pub struct ChannelSentEvent {
pub wait_ns: Option<u64>,
pub closed: bool,
}Fields
wait_ns: Option<u64>Observed wait duration in nanoseconds, if this operation suspended.
closed: boolTrue if the send failed because the other side was gone.