PullChangesResponse

Struct PullChangesResponse 

pub struct PullChangesResponse {
    pub stream_id: StreamId,
    pub from_seq_no: SeqNo,
    pub next_seq_no: SeqNo,
    pub changes: Vec<StampedChange>,
    pub truncated: bool,
    pub compacted_before_seq_no: Option<SeqNo>,
}
Delta response for one pull step.

Fields

stream_id: StreamId

Stream identity chosen during process handshake.

from_seq_no: SeqNo

Echo of request cursor.

next_seq_no: SeqNo

Next cursor the caller should request.

changes: Vec<StampedChange>

Returned changes in ascending seq_no.

truncated: bool

true when additional changes are available after this batch.

compacted_before_seq_no: Option<SeqNo>

When present, requested history before this cursor was compacted away.

Consumers should rebuild from a checkpoint and resume from this cursor.