pub struct RequestEntity {
pub service_name: String,
pub method_name: String,
pub args_json: Json,
}Expand description
Correlation token for RPC is the request entity id propagated in metadata.
The receiver generates a fresh response entity id and emits request -> response.
Fields
service_name: StringService name portion of the RPC endpoint.
Example: for vfs.lookupItem, this is vfs.
method_name: StringMethod name portion of the RPC endpoint.
Example: for vfs.lookupItem, this is lookupItem.
args_json: JsonJSON-encoded request arguments.
This is always valid JSON and should be [] when the method has no args.